#ifndef SEEN_SP_SELTRANS_HANDLES_H
#define SEEN_SP_SELTRANS_HANDLES_H

/*
 * Seltrans knots
 *
 * Authors:
 *   Lauris Kaplinski <lauris@kaplinski.com>
 *
 * Copyright (C) 1999-2002 authors
 *
 * Released under GNU GPL, read the file 'COPYING' for more information
 */

#include <2geom/forward.h>
#include <gdk/gdk.h>
#include "enums.h"
#include "verbs.h"

namespace Inkscape
{
  class SelTrans;
}

// Colours are RRGGBBAA:      FILL,       OVER&DRAG,  STROKE,     OVER&DRAG
guint32 const DEF_COLOR[] = { 0x000000ff, 0x00ff6600, 0x000000ff, 0x000000ff };
guint32 const CEN_COLOR[] = { 0x00000000, 0x00000000, 0x000000ff, 0xff0000b0 };
guint32 const RED_COLOR[] = { 0x336699b7, 0x00000000, 0x336699b7, 0x336699b7 };

enum SPSelTransType {
    HANDLE_STRETCH,
    HANDLE_SCALE,
    HANDLE_SKEW,
    HANDLE_ROTATE,
    HANDLE_CENTER,
    HANDLE_ALIGN
};

const int AlignVerb[6] = {
    SP_VERB_ALIGN_VERTICAL_TOP,
    SP_VERB_ALIGN_HORIZONTAL_RIGHT,
    SP_VERB_ALIGN_VERTICAL_BOTTOM,
    SP_VERB_ALIGN_HORIZONTAL_LEFT,
    SP_VERB_ALIGN_VERTICAL_CENTER,
    SP_VERB_ALIGN_HORIZONTAL_CENTER
};

struct SPSelTransTypeInfo {
        guint32 const *color;
        gchar const *tip;
};
// One per handle type in order
extern SPSelTransTypeInfo const handtypes[6];

struct SPSelTransHandle;

struct SPSelTransHandle {
        SPSelTransType type;
	SPAnchorType anchor;
	GdkCursorType cursor;
	guint control;
	gdouble x, y;
};
// These are 4 * each handle type + 1 for center
int const NUMHANDS = 23;
extern SPSelTransHandle const hands[NUMHANDS];

#endif // SEEN_SP_SELTRANS_HANDLES_H

/*
  Local Variables:
  mode:c++
  c-file-style:"stroustrup"
  c-file-offsets:((innamespace . 0)(inline-open . 0)(case-label . +))
  indent-tabs-mode:nil
  fill-column:99
  End:
*/
// vim: filetype=cpp:expandtab:shiftwidth=4:tabstop=8:softtabstop=4 :


